==> skrooge_1.1.1.orig.tar.bz2: skrooge-1.1.1/skgbasegui/kdatevalidator.h <==
/*
  This file is part of libkdepim.

  Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
  Copyright (c) 2002 David Jarvie <software@astrojar.org.uk>
  Copyright (c) 2004 Tobias Koenig <tokoe@kde.org>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  Boston, MA 02110-1301, USA.
*/

#ifndef KDEPIM_KDATEVALIDATOR_H
#define KDEPIM_KDATEVALIDATOR_H

#include <QValidator>

#include "skgbasegui_export.h"

namespace KPIM
{

class KDateValidatorPrivate;

class SKGBASEGUI_EXPORT KDateValidator : public QValidator
{
    Q_OBJECT
    Q_ENUMS(FixupBehavior)
public:
    enum FixupBehavior {
        NoFixup = 0,
        FixupCurrent,
        FixupForward,
        FixupBackward
    };

    KDateValidator(QObject* parent = 0);
    virtual ~KDateValidator();

    void setKeywords(const QStringList& keywords);
    QStringList keywords() const;

    void setFixupBehavior(FixupBehavior behavior);
    FixupBehavior fixupBehavior() const;

    /*reimp*/
    State validate(QString& input, int& pos) const;
    /*reimp*/
    void fixup(QString& input) const;

private:
    KDateValidatorPrivate* const d;
};

}

#endif

==> skrooge-1.7.5.tar.bz2: skrooge-1.7.5/skgbasegui/kdatevalidator.h <==
/*
  This file is part of libkdepim.

  Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
  Copyright (c) 2002 David Jarvie <software@astrojar.org.uk>
  Copyright (c) 2004 Tobias Koenig <tokoe@kde.org>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  Boston, MA 02110-1301, USA.
*/

#ifndef KDEPIM_KDATEVALIDATOR_H
#define KDEPIM_KDATEVALIDATOR_H

#include <QValidator>

#include "skgbasegui_export.h"

namespace KPIM
{

class KDateValidatorPrivate;

class SKGBASEGUI_EXPORT KDateValidator : public QValidator
{
    Q_OBJECT
    Q_ENUMS(FixupBehavior)
public:
    enum FixupBehavior {
        NoFixup = 0,
        FixupCurrent,
        FixupForward,
        FixupBackward
    };

    explicit KDateValidator(QObject* parent = 0);
    virtual ~KDateValidator();

    void setKeywords(const QStringList& keywords);
    QStringList keywords() const;

    void setFixupBehavior(FixupBehavior behavior);
    FixupBehavior fixupBehavior() const;

    /*reimp*/
    State validate(QString& input, int& pos) const;
    /*reimp*/
    void fixup(QString& input) const;

private:
    KDateValidatorPrivate* const d;
};

}

#endif
